@@ -82,8 +82,10 @@ PASSWORD_PARAMETER_NAMES = (
     'GlancePassword',
     'GnocchiPassword',
     'HAProxyStatsPassword',
+    'HeatAuthEncryptionKey',
     'HeatPassword',
     'HeatStackDomainAdminPassword',
+    'HorizonSecret',
     'IronicPassword',
     'LibvirtTLSPassword',
     'KeystoneCredential0',
@@ -94,15 +96,19 @@ PASSWORD_PARAMETER_NAMES = (
     'ManilaPassword',
     'MistralPassword',
     'MysqlClustercheckPassword',
+    'MysqlRootPassword',
     'NeutronMetadataProxySharedSecret',
     'NeutronPassword',
     'NovaPassword',
     'NovajoinPassword',
     'MigrationSshKey',
+    'OctaviaCaKeyPassphrase',
     'OctaviaHeartbeatKey',
     'OctaviaPassword',
     'PacemakerRemoteAuthkey',
     'PankoPassword',
+    'PcsdPassword',
+    'RabbitCookie',
     'RabbitPassword',
     'RedisPassword',
     'SaharaPassword',
@@ -113,6 +119,14 @@ PASSWORD_PARAMETER_NAMES = (
     'TrovePassword',
     'ZaqarPassword',
 )
+# List of legacy resource names from overcloud.yaml
+LEGACY_HEAT_PASSWORD_RESOURCE_NAMES = (
+    'HeatAuthEncryptionKey',
+    'HorizonSecret',
+    'MysqlRootPassword',
+    'PcsdPassword',
+    'RabbitCookie',
+)
 
 PLAN_NAME_PATTERN = '^[a-zA-Z0-9-]+$'
 
