@@ -14,6 +14,7 @@
 # under the License.
 import mock
 
+
 from heatclient import exc as heatexceptions
 from mistral_lib import actions
 from oslo_concurrency import processutils
@@ -70,6 +71,77 @@ ROLES_DATA_YAML_CONTENTS = """
     - OS::TripleO::Services::Kernel
 """
 
+SAMPLE_ROLE = """
+###############################################################################
+# Role: sample                                                                #
+###############################################################################
+- name: sample
+  description: |
+    Sample!
+  networks:
+    - InternalApi
+  HostnameFormatDefault: '%stackname%-sample-%index%'
+  ServicesDefault:
+    - OS::TripleO::Services::Ntp
+"""
+
+SAMPLE_ROLE_OBJ = {
+    'HostnameFormatDefault': '%stackname%-sample-%index%',
+    'ServicesDefault': ['OS::TripleO::Services::Ntp'],
+    'description': 'Sample!\n',
+    'name': 'sample',
+    'networks': ['InternalApi']
+}
+
+
+SAMPLE_ROLE_2 = """
+###############################################################################
+# Role: sample2                                                               #
+###############################################################################
+- name: sample2
+  description: |
+    Sample2!
+  networks:
+    - InternalApi
+  HostnameFormatDefault: '%stackname%-sample-%index%'
+  ServicesDefault:
+    - OS::TripleO::Services::Ntp
+"""
+
+SAMPLE_ROLE_2_OBJ = {
+    'HostnameFormatDefault': '%stackname%-sample-%index%',
+    'ServicesDefault': ['OS::TripleO::Services::Ntp'],
+    'description': 'Sample2!\n',
+    'name': 'sample2',
+    'networks': ['InternalApi']
+}
+
+UPDATED_ROLE = """
+###############################################################################
+# Role: sample                                                                #
+###############################################################################
+- name: sample
+  description: |
+    Sample!
+  networks:
+    - InternalApi
+    - ExternalApi
+  tags:
+    - primary
+  HostnameFormatDefault: '%stackname%-sample-%index%'
+  ServicesDefault:
+    - OS::TripleO::Services::Ntp
+"""
+
+UPDATED_ROLE_OBJ = {
+    'HostnameFormatDefault': '%stackname%-sample-%index%',
+    'ServicesDefault': ['OS::TripleO::Services::Ntp'],
+    'description': 'Sample!\n',
+    'name': 'sample',
+    'networks': ['InternalApi', 'ExternalApi'],
+    'tags': ['primary']
+}
+
 
 class CreateContainerActionTest(base.TestCase):
 
@@ -201,7 +273,6 @@ class DeletePlanActionTest(base.TestCase):
         swift = mock.MagicMock()
         swift.get_account.return_value = ({}, [
             {'name': self.container_name},
-            {'name': "%s-swift-rings" % self.container_name},
             {'name': 'test'},
         ])
         swift.get_container.return_value = (
@@ -233,39 +304,7 @@ class DeletePlanActionTest(base.TestCase):
         swift.delete_object.assert_has_calls(
             mock_calls, any_order=True)
 
-        mock_calls = [
-            mock.call(self.container_name),
-            mock.call("%s-swift-rings" % self.container_name)
-        ]
-        self.assertEqual(2, swift.delete_container.call_count)
-        swift.delete_container.assert_has_calls(mock_calls)
-
-    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
-    @mock.patch(
-        'tripleo_common.actions.base.TripleOAction.get_orchestration_client')
-    def test_run_no_containers(
-            self, get_orchestration_client, get_obj_client_mock):
-
-        # setup swift
-        swift = mock.MagicMock()
-        # There are no swift containers because they were either accidentally
-        # removed or not created.
-        swift.get_account.return_value = ({}, [])
-
-        get_obj_client_mock.return_value = swift
-
-        # setup heat
-        heat = mock.MagicMock()
-        heat.stacks.get = mock.Mock(
-            side_effect=heatexceptions.HTTPNotFound)
-        get_orchestration_client.return_value = heat
-
-        action = plan.DeletePlanAction(self.container_name)
-        action.run(self.ctx)
-
-        # The operation was successfully finished and we didn't try to remove
-        # nonexistent containers.
-        self.assertEqual(0, swift.delete_container.call_count)
+        swift.delete_container.assert_called_with(self.container_name)
 
 
 class ListRolesActionTest(base.TestCase):
@@ -400,3 +439,154 @@ class ExportPlanActionTest(base.TestCase):
 
         error = "Error while creating a tarball"
         self.assertIn(error, result.error)
+
+
+class UpdateNetworksActionTest(base.TestCase):
+
+    def setUp(self):
+        super(UpdateNetworksActionTest, self).setUp()
+        self.current_networks = [
+            {
+                'name': 'FirstCurrentNetwork'
+            }
+        ]
+        self.ctx = mock.MagicMock()
+
+    def test_run_success(self):
+        networks = [
+            {
+                'name': 'MyFirstNetwork'
+            }
+        ]
+
+        action = plan.UpdateNetworksAction(networks, self.current_networks,
+                                           replace_all=False)
+        result = action.run(self.ctx)
+
+        expected = [
+            {'name': 'FirstCurrentNetwork'},
+            {'name': 'MyFirstNetwork'}
+        ]
+        self.assertEqual(expected,
+                         sorted(result.data['network_data'],
+                                key=lambda k: k['name']))
+
+    def test_run_success_replace(self):
+        networks = [
+            {
+                'name': 'MyReplacementNetwork'
+            }
+        ]
+
+        action = plan.UpdateNetworksAction(networks, self.current_networks,
+                                           replace_all=True)
+        result = action.run(self.ctx)
+        expected = [
+            {'name': 'MyReplacementNetwork'}
+        ]
+        self.assertEqual({"network_data": expected}, result.data)
+
+
+class ValidateRolesDataActionTest(base.TestCase):
+
+    def setUp(self):
+        super(ValidateRolesDataActionTest, self).setUp()
+        self.container = 'overcloud'
+        self.ctx = mock.MagicMock()
+
+    def test_valid_roles(self):
+        current_roles = [SAMPLE_ROLE_OBJ]
+        requested_roles = [SAMPLE_ROLE_OBJ]
+        action = plan.ValidateRolesDataAction(requested_roles, current_roles)
+        result = action.run(self.ctx)
+        self.assertTrue(result.data)
+
+    def test_invalid_roles(self):
+        current_roles = [SAMPLE_ROLE_2_OBJ]
+        requested_roles = [SAMPLE_ROLE_OBJ, ]
+        action = plan.ValidateRolesDataAction(requested_roles, current_roles)
+        result = action.run(self.ctx)
+        self.assertTrue(result.error)
+
+    def test_validate_role_yaml_missing_name(self):
+        role = SAMPLE_ROLE_OBJ.copy()
+        del role['name']
+        current_roles = [SAMPLE_ROLE_OBJ]
+        requested_roles = [role, ]
+        action = plan.ValidateRolesDataAction(requested_roles, current_roles)
+        result = action.run(self.ctx)
+        self.assertTrue(result.error)
+
+    def test_validate_role_yaml_invalid_type(self):
+        role = SAMPLE_ROLE_OBJ.copy()
+        role['CountDefault'] = 'should not be a string'
+        current_roles = [SAMPLE_ROLE_OBJ]
+        requested_roles = [role, ]
+        action = plan.ValidateRolesDataAction(requested_roles, current_roles)
+        result = action.run(self.ctx)
+        self.assertTrue(result.error)
+
+
+class UpdateRolesActionTest(base.TestCase):
+
+    def setUp(self):
+        super(UpdateRolesActionTest, self).setUp()
+        self.container = 'overcloud'
+        self.ctx = mock.MagicMock()
+        self.current_roles = [SAMPLE_ROLE_OBJ, SAMPLE_ROLE_2_OBJ]
+
+    def test_no_primary_roles(self):
+        updated_role = UPDATED_ROLE_OBJ.copy()
+        del updated_role['tags']
+        action = plan.UpdateRolesAction([updated_role],
+                                        self.current_roles,
+                                        True, self.container)
+
+        self.assertRaises(exception.RoleMetadataError, action.run, self.ctx)
+
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
+    def test_update_some_roles(self, get_obj_client_mock):
+        # Setup
+        swift = mock.MagicMock()
+        get_obj_client_mock.return_value = swift
+
+        action = plan.UpdateRolesAction([UPDATED_ROLE_OBJ],
+                                        self.current_roles,
+                                        False, self.container)
+        result = action.run(self.ctx)
+
+        self.assertEqual(result.data,
+                         {'roles': [SAMPLE_ROLE_2_OBJ, UPDATED_ROLE_OBJ]})
+
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
+    def test_update_replace_roles(self, get_obj_client_mock):
+        # Setup
+        swift = mock.MagicMock()
+        get_obj_client_mock.return_value = swift
+
+        action = plan.UpdateRolesAction([UPDATED_ROLE_OBJ],
+                                        self.current_roles,
+                                        True, self.container)
+        result = action.run(self.ctx)
+
+        self.assertEqual(result.data, {'roles': [UPDATED_ROLE_OBJ, ]})
+
+
+class GatherRolesActionTest(base.TestCase):
+
+    def setUp(self):
+        super(GatherRolesActionTest, self).setUp()
+        self.container = 'overcloud'
+        self.ctx = mock.MagicMock()
+        self.current_roles = [SAMPLE_ROLE_OBJ, SAMPLE_ROLE_2_OBJ]
+        self.available_role = SAMPLE_ROLE_OBJ.copy()
+        self.available_role['name'] = 'test'
+
+    def test_roles_gathered(self):
+        action = plan.GatherRolesAction(['sample', 'test'], self.current_roles,
+                                        [self.available_role])
+        result = action.run(self.ctx)
+
+        # assert that a role was loaded from self.current_roles
+        self.assertTrue(result.data['gathered_roles'],
+                        [SAMPLE_ROLE_OBJ, self.available_role])
