@@ -167,7 +167,7 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'namespace': 'docker.io/tripleomaster',
                 'ceph_namespace': 'docker.io/ceph',
                 'ceph_image': 'daemon',
-                'ceph_tag': 'tag-stable-3.0-luminous-centos-7',
+                'ceph_tag': 'v3.0.1-stable-3.0-luminous-centos-7-x86_64',
                 'logging': 'files',
                 'name_prefix': 'centos-binary-',
                 'name_suffix': '',
